<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:advertising="http://www.mad-hacking.net/schema/dms/ext/advertising"
				xmlns:social="http://www.mad-hacking.net/schema/dms/ext/social">

	<!-- Import base/* stylesheets -->
	<xsl:import href="base/blogpost.xsl" />
	<xsl:import href="base/document.xsl" />
	<xsl:import href="base/documentgroup.xsl" />
	<xsl:import href="base/chapter.xsl" />
	<xsl:import href="base/common.xsl" />
	<xsl:import href="base/utility.xsl" />
	<xsl:import href="base/figure.xsl" />
	<xsl:import href="base/index.xsl" />
	<xsl:import href="base/lists.xsl" />
	<xsl:import href="base/notes.xsl" />
	<xsl:import href="base/references.xsl" />
	<xsl:import href="base/tables.xsl" />

	<!-- 
		<meta> tag generation
	 -->

	<!-- Base <meta> include template.  Called from layout.xsl to include <meta> tags for modules -->
	<xsl:template name="dms:meta-include">
		<xsl:apply-templates select="/" mode="dms:meta-include" />
		<xsl:call-template name="social:meta-include" />
	</xsl:template>

	<!-- Dummy templates for <meta> includes -->
	<xsl:template name="social:meta-include" />

	<!-- The following template ensures that we keep going when we hit an unrecognised element -->	
	<xsl:template match="*" mode="dms:meta-include">
		<xsl:apply-templates mode="dms:meta-include" />
	</xsl:template>

	<!-- The following template ensures that no output is generated when encountering text nodes -->
	<xsl:template match="text()" mode="dms:meta-include" />

	<!-- 
		CSS Includes
	 -->

	<!-- Base CSS include template.  Called from layout.xsl to include CSS files for modules -->
	<xsl:template name="dms:css-include">
		<xsl:apply-templates select="/" mode="dms:css-include" />
		<xsl:call-template name="advertising:css-include" />
		<xsl:call-template name="social:css-include" />
	</xsl:template>

	<!-- The following templates handle all TOP LEVEL elements defined in the BASE template set. -->

	<!-- CSS include template for doc:index (document index nodes) -->
 	<xsl:template match="doc:index[1]" mode="dms:css-include">
		<xsl:if test="count(current() | /descendant::doc:index[1])=1">
			<xsl:call-template name="dms:css-include-navigation-main-menu" />
			<xsl:call-template name="dms:css-include-navigation-breadcrumbs" />
			<xsl:call-template name="dms:css-include-navigation-site-index" />
			<xsl:call-template name="dms:css-include-text-styling" />
		</xsl:if>
	</xsl:template>

	<!-- CSS include template for doc:document, doc:documentgroup & doc:blogpost elements -->
	<xsl:template match="doc:document[1]|doc:documentgroup[1]|doc:blogpost[1]" mode="dms:css-include">
		<xsl:if test="count(current() | (/descendant::doc:document|/descendant::doc:documentgroup)[1])=1">
			<xsl:call-template name="dms:css-include-navigation-main-menu" />
			<xsl:call-template name="dms:css-include-navigation-breadcrumbs" />
			<xsl:call-template name="dms:css-include-document" />
			<xsl:call-template name="dms:css-include-text-styling" />
		</xsl:if>
		<xsl:apply-templates mode="dms:css-include" />
	</xsl:template>
	
	<!-- CSS include template for doc:chapter elements -->
	<xsl:template match="doc:chapter[1]" mode="dms:css-include">
		<xsl:if test="count(current() | /descendant::doc:chapter[1]) = 1">
			<xsl:call-template name="dms:css-include-navigation-main-menu" />
			<xsl:call-template name="dms:css-include-navigation-breadcrumbs" />
			<xsl:call-template name="dms:css-include-navigation-chapter" />
			<xsl:call-template name="dms:css-include-text-styling" />
		</xsl:if>
		<xsl:apply-templates mode="dms:css-include" />
	</xsl:template>

	<!-- Dummy templates for CSS includes -->
	<xsl:template name="dms:css-include-navigation-main-menu" />
	<xsl:template name="dms:css-include-navigation-breadcrumbs" />
	<xsl:template name="dms:css-include-navigation-chapter" />
	<xsl:template name="advertising:css-include" />
	<xsl:template name="social:css-include" />

	<!-- The following template ensures that no output is generated when encountering text nodes -->
	<xsl:template match="text()" mode="dms:css-include" />

	<!-- 
		JavaScript Includes
	 -->

	<!-- Base JS include template.  Called from layout.xsl to include JavaScript files for modules -->
	<xsl:template name="dms:js-include">
		<xsl:apply-templates select="/" mode="dms:js-include" />
		<xsl:call-template name="social:js-include" />
	</xsl:template>

	<!-- JS include template for doc:index (document index nodes) -->
 	<xsl:template match="doc:index[1]" mode="dms:js-include">
		<xsl:if test="count(current() | /descendant::doc:index[1])=1">
			<script type="text/javascript" src="/scripts/add-dom-load-event.js">&nbsp;</script>
			<script type="text/javascript" src="/scripts/SimpleShowHide.js">&nbsp;</script>
		</xsl:if>
	</xsl:template>

	<!-- JS include template for doc:document, doc:documentgroup & doc:blogpost elements -->
	<xsl:template match="doc:document[1]|doc:documentgroup[1]|doc:blogpost[1]" mode="dms:js-include">
		<xsl:if test="count(current() | (/descendant::doc:document|/descendant::doc:documentgroup)[1])=1">
			<script type="text/javascript" src="/scripts/add-dom-load-event.js">&nbsp;</script>
			<script type="text/javascript" src="/scripts/SimpleShowHide.js">&nbsp;</script>
		</xsl:if>
	</xsl:template>
		
	<!-- Dummy templates for JS includes -->
	<xsl:template name="social:js-include" />

	<!-- The following template ensures that we keep going when we hit an unrecognised element -->	
	<xsl:template match="*" mode="dms:js-include">
		<xsl:apply-templates mode="dms:js-include" />
	</xsl:template>

	<!-- The following template ensures that no output is generated when encountering text nodes -->
	<xsl:template match="text()" mode="dms:js-include" />

	<!-- 
		Misc <html> generation, often used to include <script> tags at the end of the page.
	 -->

	<!-- Base <html> include template.  Called from layout.xsl to include <html> markup for modules -->
	<xsl:template name="dms:html-include">
		<div id="dms-hidden-html">
			<xsl:apply-templates select="/" mode="dms:html-include" />
			<xsl:call-template name="social:html-include" />
			&nbsp;
		</div>
	</xsl:template>

	<!-- Dummy templates for <html> includes -->
	<xsl:template name="social:html-include" />

	<!-- The following template ensures that we keep going when we hit an unrecognised element -->	
	<xsl:template match="*" mode="dms:html-include">
		<xsl:apply-templates mode="dms:html-include" />
	</xsl:template>

	<!-- The following template ensures that no output is generated when encountering text nodes -->
	<xsl:template match="text()" mode="dms:html-include" />

</xsl:stylesheet>