<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY ldquo "&#8220;"> <!ENTITY rdquo "&#8221;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:advertising="http://www.mad-hacking.net/schema/dms/ext/advertising"
				xmlns:social="http://www.mad-hacking.net/schema/dms/ext/social">


	<xsl:template name="dms:css-include-text-styling">
		<link rel="stylesheet" type="text/css" href="/style/dms/css/base/text-styling.css" />
		<link rel="stylesheet" type="text/css" href="/style/dms/css/base/tables.css" />
	</xsl:template>

	<!--
		Template to match <doc:title> nodes.  An <h1> element is created by applying templates to the contents.
	-->
	<xsl:template match="doc:title">
		<h1 class="block"><xsl:apply-templates /></h1>
	</xsl:template>	

	<!--
		Template to match 1st level <doc:section> nodes.  An <h2> element is created from the @title attribute.
	-->
	<xsl:template match="doc:section">
		<h2 id="{@id}"><xsl:value-of select="@title" /></h2>	
		<xsl:apply-templates />
		<xsl:if test="count(preceding-sibling::doc:section) &lt; 3">
			<xsl:call-template name="advertising:insert-flow-advert" />
		</xsl:if>
	</xsl:template>

	<!--
		Template to match 2nd level <doc:section> nodes.  An <h3> element is created from the @title attribute.
	-->
	<xsl:template match="doc:section/doc:section">
		<h3><xsl:value-of select="@title" /></h3>	
		<xsl:apply-templates />
	</xsl:template>

	<!--
		Template to match Nth level <doc:section> nodes.  An <h4> element is created from the @title attribute.
	-->
	<xsl:template match="doc:section/doc:section/doc:section">
		<h4><xsl:value-of select="@title" /></h4>	
		<xsl:apply-templates />
	</xsl:template>


	<!--
		Template to match <doc:para> nodes.  A <p> element is created by applying templates to the contents.
	-->	
	<xsl:template match="doc:para">
		<p>
			<xsl:apply-templates />
		</p>	
	</xsl:template>

	<!--
		Template to match <doc:em> nodes.  A <em> element is created by applying templates to the contents.
	-->	
	<xsl:template match="doc:em">
		<em><xsl:apply-templates /></em>
	</xsl:template>
	
	<!--
		Template to match <doc:keyword> nodes.  A <span class="mono"> element is created by applying templates
		to the contents.
	-->	
	<xsl:template match="doc:keyword">
		<span class="mono">
			<xsl:apply-templates />
		</span>	
	</xsl:template>

	<!--
		Template to match <doc:quote> nodes.  A left and right double quote are generated surounding an <em>
		element	created by applying templates to the contents.
	-->	
	<xsl:template match="doc:quote">
		&ldquo;<em><xsl:apply-templates /></em>&rdquo;
	</xsl:template>

	<!--
		Template to match <doc:strong> nodes.  A <strong> element is created by applying templates to the contents.
	-->	
	<xsl:template match="doc:strong">
		<strong><xsl:apply-templates /></strong>
	</xsl:template>
	
	<!-- Dummy template to be used when inserting advertisements -->
	<xsl:template name="advertising:insert-flow-advert" />
	
	<!-- Dummy template to be used when inserting social networking icons -->
	<xsl:template name="social:social-networking" />

</xsl:stylesheet>