<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> <!ENTITY darr "&#8595;"> <!ENTITY uarr "&#8593;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:social="http://www.mad-hacking.net/schema/dms/ext/social">

	<xsl:template name="dms:css-include-document">
		<link rel="stylesheet" type="text/css" href="/style/dms/css/base/document.css" />
	</xsl:template>
	
	<!-- 
		Template to match <doc:document> nodes.  A <div> is created with @id="dms-base-document" and 
		@class="dms-base-document" by applying templates to the contents.
	 -->
	<xsl:template match="doc:document">
		<div id="dms-base-document" class="dms-base-document">
			<xsl:apply-templates />
			<xsl:call-template name="social:social-networking" />
		</div>
	</xsl:template>

	<!-- Dummy template for social:social-networking -->
	<xsl:template name="social:social-networking" />

	<xsl:template match="doc:document/doc:meta" />

	<!-- 
		Template to match <doc:document>/<doc:abstract> nodes.  An <h2> element is created 	containing the text
		"Abstract".  Templates are then applied to generate abstract contents when displayed in	the default mode.  
	 -->
	<xsl:template match="doc:document/doc:abstract">
		<h2>Abstract</h2>
		<xsl:apply-templates />
	</xsl:template>	
	
	<!-- Template to match <doc:contents> nodes -->
	<xsl:template match="doc:contents">
		<h2>Contents</h2>
		<ul id="dms-base-document-contents">
			<xsl:apply-templates mode="dms:contents-node"/>
		</ul>
	</xsl:template>	
	
	<!-- Template to match contents parts -->
	<xsl:template match="doc:part" mode="dms:contents-node">
		<li class="dms-base-document-contents-part">
			<xsl:value-of select="@title" />
			<ul class="dms-base-document-contents-chapters">
				<xsl:apply-templates mode="dms:contents-node" />
			</ul> 
		</li>
	</xsl:template>	
	
	
	<!-- Template to match contents/parts/localref elements (with chapter link), find them in the index
		 and use the template below -->
	<xsl:template match="doc:localref[@chapter-id]" mode="dms:contents-node">
		<xsl:variable name="document-id" select="@document-id" />
		<xsl:variable name="chapter-id" select="@chapter-id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]//*[@id=concat($chapter-id, '')]" mode="dms:contents-node" />
	</xsl:template>
	
	<!-- Template to match contents/parts/localref elements (without chapter link), find them in the index
		 and use the template below -->
	<xsl:template match="doc:localref" mode="dms:contents-node">
		<xsl:variable name="document-id" select="@document-id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:contents-node" />
	</xsl:template>

	
	<!-- Template to match document elements in site-index.xml -->
	<xsl:template match="doc:document" mode="dms:contents-node">
		<li class="dms-base-document-contents-chapter">
			<span class="hide-no-dom pointer" name="SimpleShowHide:Trigger" show-hide-target-name="dms-base-document-{@id}" initial-state="hidden" >
				<img name="SimpleShowHide:Show" src="/style/site/icons/arrow_open.gif" width="11" height="9" alt="+" />
				<img class="hidden" name="SimpleShowHide:Hide" src="/style/site/icons/arrow_close.gif" width="11" height="9" alt="-" />
			</span>
			<a href="{@href}"><xsl:value-of select="normalize-space(doc:title)" /></a>

			<ul name="dms-base-document-{@id}" class="dms-base-document-contents-sections hidden" >
				<xsl:apply-templates select="doc:chapter" mode="dms:contents-node" />
			</ul>
		</li>
	</xsl:template>	

	<!-- Template to match contents parts chapters -->
	<xsl:template match="doc:chapter" mode="dms:contents-node">
		<li class="dms-base-document-contents-chapter">
			<xsl:apply-templates select="document(@href)/*" mode="dms:contents-doc">
				<xsl:with-param name="href" select="@href" />
				<xsl:with-param name="chapter-id" select="@id" />
				<xsl:with-param name="document-id" select="../@id" />
			</xsl:apply-templates>
		</li>
	</xsl:template>	
	
	<!-- The template above uses this template to perform more specific actions on the same node -->	
	<xsl:template match="/doc:chapter" mode="dms:contents-doc">
		<xsl:param name="href" />
		<xsl:param name="chapter-id" />
		<xsl:param name="document-id" />

		<span class="hide-no-dom pointer" name="SimpleShowHide:Trigger" show-hide-target-name="dms-base-document-{$document-id}-chapter-{$chapter-id}" initial-state="hidden" >
			<img name="SimpleShowHide:Show" src="/style/site/icons/arrow_open.gif" width="11" height="9" alt="+" />
			<img class="hidden" name="SimpleShowHide:Hide" src="/style/site/icons/arrow_close.gif" width="11" height="9" alt="-" />
		</span>
		<a href="{$href}">
			<xsl:value-of select="doc:title" />
		</a>
					
		<ul name="dms-base-document-{$document-id}-chapter-{$chapter-id}" class="dms-base-document-contents-sections hidden" >
			<xsl:apply-templates select="doc:section" mode="dms:contents-doc">
				<xsl:with-param name="href" select="$href" />
			</xsl:apply-templates>
		</ul>
	</xsl:template>

	<xsl:template match="/doc:chapter/doc:section" mode="dms:contents-doc">
		<xsl:param name="href" />

		<li class="dms-base-document-contents-section">
			<a href="{$href}#{@id}">
				<xsl:value-of select="@title" />
			</a>
		</li>
	</xsl:template>

</xsl:stylesheet>