<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> <!ENTITY darr "&#8595;"> <!ENTITY uarr "&#8593;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents" 
				xmlns:social="http://www.mad-hacking.net/schema/dms/ext/social">

	<!-- 
		Template to match <doc:documentgroup> nodes.  A <div> is created with @id="dms-base-document" and 
		@class="dms-base-documentgroup" by applying templates to the contents.
	 -->
	<xsl:template match="doc:documentgroup">
		<div id="dms-base-document" class="dms-base-documentgroup">
			<xsl:apply-templates />
			<xsl:call-template name="social:social-networking" />
		</div>
	</xsl:template>

	<!-- Dummy template for social:social-networking -->
	<xsl:template name="social:social-networking" />

	<!--
		Template to match <doc:documentgroup>/<doc:abstract>/<doc:linkedonly> nodes to hide them in the
		default mode.
	-->
	<xsl:template match="doc:documentgroup/doc:abstract/doc:linkedonly" />
	
	<!--
		Template to match <doc:documentgroup>/<doc:meta> nodes to hide them in the
		default mode.
	-->
	<xsl:template match="doc:documentgroup/doc:meta" />
	
	<!--
		Template to match <doc:documents> nodes.  A <div> is created with @class="dms-base-document-listing" and
		filled by applying templates in "documentgroup-index" mode to the children of the node matching the current 
		<doc:documentgroup> node in the site-index file.
	-->
	<xsl:template match="doc:documents">
		<div class="dms-base-document-listing">
			<xsl:apply-templates />
		</div>
	</xsl:template>

	<xsl:template match="doc:documents/doc:children">
		<xsl:variable name="id" select="ancestor::doc:documentgroup/@id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($id, '')]/*" mode="dms:documentgroup-index">
			<xsl:sort select="doc:title" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="doc:documents/doc:children-of">
		<xsl:variable name="id" select="@id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($id, '')]/*" mode="dms:documentgroup-index">
			<xsl:sort select="doc:title" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="doc:documents/doc:document">
		<xsl:variable name="id" select="@id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($id, '')]" mode="dms:documentgroup-index">
			<xsl:sort select="doc:title" />
		</xsl:apply-templates>
	</xsl:template>

	<!--
		Template to match <doc:document> and <doc:documentgroup> nodes in the site-index file.  The file linked
		in @href is opened and templates are applied in "documentgroup-contents" mode.
	-->
	<xsl:template match="doc:document|doc:documentgroup" mode="dms:documentgroup-index">
		<xsl:apply-templates select="document(@href)/*" mode="dms:documentgroup-contents">
			<xsl:with-param name="href" select="@href" />
			<xsl:with-param name="id" select="@id" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- Template to quench all nodes but those we've already matched -->
	<xsl:template match="doc:*" mode="dms:documentgroup-index" />
	
	<!--
		Template to match <doc:document> nodes in "documentgroup-contents" mode.  This template is used to process the file
		opened by the "documentgroup-index" mode template above.  A <div> is created with @class="dms-base-document" containing
		an <a> element pointing to the document, a <div> containing the basic abstract and a <div> containing the
		extended abstract if present. 
	-->
	<xsl:template match="/doc:document" mode="dms:documentgroup-contents">
		<xsl:param name="href" />
		<xsl:param name="id" />

		<div class="dms-base-document">
			<a href="{$href}">
				<span class="dms-base-header">
					<xsl:value-of select="doc:title" />
				</span>
			</a>
			<div class="dms-base-basic-abstract" name="basic-abstract-{$id}">
				<xsl:apply-templates select="doc:abstract/doc:basic/*" />
			</div>
			<xsl:if test="doc:abstract/doc:extended">
				<div class="dms-base-extended-abstract hidden" name="extended-abstract-{$id}">
					<xsl:apply-templates select="doc:abstract/doc:extended/*" />
				</div>
				<div class="dms-base-footer">
					<span class="hide-no-dom pointer" name="SimpleShowHide:Trigger" show-hide-target-name="extended-abstract-{$id}" initial-state="hidden" >
						<img name="SimpleShowHide:Show" src="/style/site/icons/arrow_open.gif" width="11" height="9" alt="+" />
						<img class="hidden" name="SimpleShowHide:Hide" src="/style/site/icons/arrow_close.gif" width="11" height="9" alt="-" />
					</span>
				</div>
			</xsl:if>
		</div>
	</xsl:template>

	<!--
		Template to match <doc:document> nodes in "documentgroup-contents" mode when @visibility='hidden' or @visibility='indexonly'
		to hide them in this mode.
	-->
	<xsl:template match="/doc:document[@visibility='hidden']" mode="dms:documentgroup-contents" />
	<xsl:template match="/doc:document[@visibility='indexonly']" mode="dms:documentgroup-contents" />

	<!--
		Template to match <doc:documentgroup> nodes in "documentgroup-contents" mode.  This template is used to process the file
		opened by the "documentgroup-index" mode template above.  A <div> is created with @class="dms-base-document" containing
		an <a> element pointing to the document, a <div> containing the basic abstract and a <div> containing the
		extended abstract if present. 
	-->
	<xsl:template match="/doc:documentgroup" mode="dms:documentgroup-contents">
		<xsl:param name="href" />
		<xsl:param name="id" />

		<div class="dms-base-document">
			<a href="{$href}">
				<span class="dms-base-header">
					<xsl:value-of select="doc:title" />
				</span>
			</a>
			<div class="dms-base-basic-abstract" name="basic-abstract-{$id}">
				<xsl:apply-templates select="doc:abstract/doc:basic" />
			</div>
			<xsl:if test="doc:abstract/doc:extended">
				<div class="dms-base-extended-abstract hidden" name="extended-abstract-{$id}">
					<xsl:apply-templates select="doc:abstract/doc:extended" />
				</div>
				<div class="dms-base-footer">
					<span class="hide-no-dom pointer" name="SimpleShowHide:Trigger" show-hide-target-name="extended-abstract-{$id}" initial-state="hidden" >
						<img name="SimpleShowHide:Show" src="/style/site/icons/arrow_open.gif" width="11" height="9" alt="+" />
						<img class="hidden" name="SimpleShowHide:Hide" src="/style/site/icons/arrow_close.gif" width="11" height="9" alt="-" />
					</span>
				</div>
			</xsl:if>
		</div>
	</xsl:template>

	<!--
		Template to match <doc:documentgroup> nodes in "documentgroup-contents" mode when @visibility='hidden' or 
		@visibility='indexonly' to hide them in this mode.
	-->
	<xsl:template match="/doc:documentgroup[@visibility='hidden']" mode="dms:documentgroup-contents" />
	<xsl:template match="/doc:documentgroup[@visibility='indexonly']" mode="dms:documentgroup-contents" />

	<!--
		Template to match <doc:note> nodes to hide them in "documentgroup-contents" mode.
	-->
	<xsl:template match="doc:note" mode="dms:documentgroup-contents" />
	
</xsl:stylesheet>