<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:dms="http://www.mad-hacking.net/schema/dms">				

	<!-- Import required base stylesheets -->
	<xsl:import href="../base/utility.xsl" />

	<!-- Template for CSS stylesheet include -->
	<xsl:template match="doc:figure[1]" mode="dms:css-include">
		<xsl:if test="count(current() | /descendant::doc:figure[1])=1">
			<link rel="stylesheet" type="text/css" href="/style/dms/css/base/diagrams.css" />
		</xsl:if>
		<xsl:apply-templates mode="dms:css-include" />
	</xsl:template>
	

	<!-- Template to match a block-level figure element used to place a figure in a document -->
	<xsl:template match="doc:figure">
		<xsl:variable name="figure-id" select="@id" />
		<xsl:apply-templates select="document('../../../figure-index.xml')//descendant::doc:figure[@id=concat($figure-id, '')]" mode="dms:figure-image">
			<xsl:with-param name="align" select="@align" />
			<xsl:with-param name="document-id"><xsl:call-template name="dms:get-document-id" /></xsl:with-param>
		</xsl:apply-templates>
	</xsl:template>


	<xsl:template match="doc:figure" mode="dms:figure-image">
		<xsl:param name="align" />
		<xsl:param name="document-id" />
	
		<xsl:variable name="description">
			<xsl:apply-templates select="doc:description" />
		</xsl:variable>
		<xsl:variable name="width">
			<xsl:value-of select="doc:dimensions/@width" />
		</xsl:variable>
		<xsl:variable name="height">
			<xsl:value-of select="doc:dimensions/@height" />
		</xsl:variable>
		<xsl:variable name="href">
			<xsl:value-of select="ancestor::doc:figure-group/@base" />/<xsl:value-of select="@href" />
		</xsl:variable>
		
		<xsl:variable name="class">
			<xsl:choose>
				<xsl:when test="$align = 'right'">dms-base-figure-right</xsl:when>
				<xsl:when test="$align = 'left'">dms-base-figure-left</xsl:when>
			</xsl:choose>
		</xsl:variable>
		
		<div id="{@id}" class="dms-base-figure {$class}">
			<div class="dms-base-figure-head">
				<xsl:text>Figure </xsl:text>
				<xsl:apply-templates select="." mode="dms:figure-number">
					<xsl:with-param name="figure-group" select="$document-id" />
				</xsl:apply-templates>
			</div>
			<div class="dms-base-figure-image">
				<img src="{$href}" width="{$width}" height="{$height}" alt="Figure depicting {$description}" />
			</div>
			<div class="dms-base-figure-foot">
				<xsl:apply-templates select="doc:description" />
			</div>
		</div>
	</xsl:template>
	
	<!-- Helper template to retrieve the description of a figure from its id -->
	<xsl:template name="dms:get-figure-description" >
		<xsl:param name="figure-id" />
		<xsl:apply-templates select="document('../../../figure-index.xml')//descendant::doc:figure[@id=concat($figure-id, '')]/doc:description" />
	</xsl:template>

	<!-- Helper template to retrieve the number of a figure from its id and the figure-group -->
	<xsl:template name="dms:get-figure-number" >
		<xsl:param name="figure-id" />
		<xsl:param name="figure-group" />
		<xsl:apply-templates select="document('../../../figure-index.xml')//descendant::doc:figure[@id=concat($figure-id, '')]" mode="dms:figure-number">
			<xsl:with-param name="figure-group" select="$figure-group" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- Template to generate a figure number by matching a figure node in dms:figure-number mode -->
	<xsl:template match="doc:figure" mode="dms:figure-number">
		<xsl:param name="figure-group" />
		<xsl:number level="multiple" count="doc:figure|doc:figure-group" from="doc:figure-group[@id=concat($figure-group, '')]" />
	</xsl:template>

	<!-- Template to match an in-line figure element used as a reference to a figure -->
	<xsl:template match="doc:para/doc:figure">
		<span class="mono">
			<a href="#{@ref}">
				<xsl:text>Figure </xsl:text>
				<xsl:call-template name="dms:get-figure-number">
					<xsl:with-param name="figure-id" select="@ref" />
					<xsl:with-param name="figure-group">
						<xsl:call-template name="dms:get-document-id" />
					</xsl:with-param>
				</xsl:call-template>
				<xsl:text> [</xsl:text>
				<xsl:call-template name="dms:get-figure-description" >
					<xsl:with-param name="figure-id" select="@ref" />
				</xsl:call-template>
				<xsl:text>]</xsl:text>
			</a>
		</span>
	</xsl:template>

	<!-- 
	<xsl:template match="doc:figurea">
		<div class="diagram-left">
			<img class="diagram" src="diagrams/{@image}" width="{@width}" height="{@height}" alt="Diagram of: {@description}" /><br />
			<xsl:value-of select="@description" />
		</div>
	</xsl:template>
 	-->
 	
	<xsl:template match="doc:image">
		<xsl:choose>
			<xsl:when test="@link">
				<a href="{@link}" target="_blank">
					<img class="floatright" src="{@source}" width="{@width}" height="{@height}" alt="{@alt}" />
				</a>
			</xsl:when>
			<xsl:otherwise>
				<img class="floatright" src="{@source}" width="{@width}" height="{@height}" alt="{@alt}" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>