<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:dms="http://www.mad-hacking.net/schema/dms">				

	<!-- Template to match a block-level table element used to place a table in a document -->
	<xsl:template match="doc:table">
		<xsl:apply-templates select="." mode="dms:table-table" />
	</xsl:template>

	<xsl:template match="doc:table" mode="dms:table-table">
		<xsl:variable name="class">
			<xsl:choose>
				<xsl:when test="@align = 'right'">dms-base-table-right</xsl:when>
				<xsl:when test="@align = 'left'">dms-base-table-left</xsl:when>
			</xsl:choose>
		</xsl:variable>
		
		<div id="{@id}" class="dms-base-table {$class}">
			<div class="dms-base-table-head">
				<span>Table</span>
			</div>
			<div class="dms-base-table-table">
				<table>
					<xsl:apply-templates />
				</table>
			</div>
			<div class="dms-base-table-foot">
				<span><xsl:apply-templates select="doc:description" mode="dms:table-description" /></span>
			</div>
		</div>
	</xsl:template>

	<xsl:template match="doc:table/doc:heading/doc:layout" />

	<xsl:template match="doc:table/doc:heading/doc:row">

		<xsl:variable name="class">
			<xsl:if test="count(preceding-sibling::doc:row)=0">dms-base-table-hr-first </xsl:if>
			<xsl:if test="position()=last()">dms-base-table-hr-last </xsl:if>
		</xsl:variable>

		<tr class="dms-base-table-hr {$class}">
			<xsl:apply-templates />
		</tr>

	</xsl:template>

	<xsl:template match="doc:table/doc:heading/doc:row/doc:field">

		<xsl:variable name="class">
			<xsl:if test="position()=1">first </xsl:if>
			<xsl:if test="position()=last()">last </xsl:if>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="@colspan and @rowspan">
				<th class="{$class}" colspan="{@colspan}" rowspan="{@rowspan}"><xsl:apply-templates /></th>
			</xsl:when>
			<xsl:when test="@colspan">
				<th class="{$class}" colspan="{@colspan}"><xsl:apply-templates /></th>
			</xsl:when>
			<xsl:when test="@rowspan">
				<th class="{$class}" rowspan="{@rowspan}"><xsl:apply-templates /></th>
			</xsl:when>
			<xsl:otherwise>
				<th class="{$class}"><xsl:apply-templates /></th>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>

	<xsl:template match="doc:table/doc:body/doc:layout" />

	<xsl:template match="doc:table/doc:body/doc:row">

		<xsl:variable name="class">
			<xsl:if test="count(preceding-sibling::doc:row)=0">first </xsl:if>
			<xsl:if test="position()=last()">last </xsl:if>
			<xsl:if test="position() mod 2 = 0">even </xsl:if>
			<xsl:if test="position() mod 2 = 1">odd </xsl:if>
		</xsl:variable>

		<tr class="{$class}">
			<xsl:apply-templates />
		</tr>

	</xsl:template>
	
	<xsl:template match="doc:table/doc:body/doc:row/doc:field">

		<xsl:variable name="class">
			<xsl:if test="position()=1">first </xsl:if>
			<xsl:if test="position()=last()">last </xsl:if>
			<xsl:if test="string(number(.))!='NaN'">right </xsl:if>
		</xsl:variable>

		<td class="{$class}"><xsl:apply-templates /></td>
		
	</xsl:template>

	<xsl:template match="doc:table/doc:description" />
	
</xsl:stylesheet>