<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY ldquo "&#8220;"> <!ENTITY rdquo "&#8221;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents">

	<!-- 
		Misc functional templates 
	-->
	
	<!--
		Template to return the <title> of a document as text or "Site Index" for an <index> element.
	-->
	<xsl:template name="dms:get-page-title-text">
		<xsl:if test="/doc:*">
			<xsl:apply-templates select="/doc:*" mode="dms:get-page-title-text" /> 
		</xsl:if>
	</xsl:template>

	<xsl:template match="doc:blogpost" mode="dms:get-page-title-text">
		<xsl:apply-templates select="doc:content/doc:title" mode="dms:get-page-title-text" />
	</xsl:template>

	<xsl:template match="doc:document|doc:documentgroup|doc:chapter" mode="dms:get-page-title-text">
		<xsl:apply-templates select="doc:title" mode="dms:get-page-title-text" />
	</xsl:template>

	<xsl:template match="doc:index" mode="dms:get-page-title-text">
		Site Index
	</xsl:template>
	
	<xsl:template match="*" mode="dms:get-page-title-text" >
		<xsl:apply-templates mode="dms:get-page-title-text" />
	</xsl:template>

	<!--
		Template to return the <title> of the parent document as text.
	-->
	<xsl:template name="dms:get-parent-title-text">
		<xsl:variable name="document-id" select="/doc:*[1]/@parent-id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:get-parent-title-text-index" />
	</xsl:template>

	<xsl:template match="doc:title" mode="dms:get-parent-title-text-index">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="text()" mode="dms:get-parent-title-text-index" />
	
	<!-- 
		Template to return the @id of a document or the @parent-id of a chapter
	 -->
	<xsl:template name="dms:get-document-id">
		<xsl:apply-templates select="/" mode="dms:get-document-id" />
	</xsl:template>
	
	<xsl:template match="/doc:*" mode="dms:get-document-id">
		<xsl:value-of select="@id" />
	</xsl:template>
	
	<xsl:template match="/doc:chapter" mode="dms:get-document-id">
		<xsl:value-of select="@parent-id" />
	</xsl:template>
	
	<!--
		Template to return the URL of the current page
	-->
	<xsl:template name="dms:get-page-url">
		<xsl:apply-templates select="/" mode="dms:get-page-url" />
	</xsl:template>

	<xsl:template match="/doc:*" mode="dms:get-page-url">
		<xsl:variable name="document-id" select="@id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:get-page-url-index" />
	</xsl:template>

	<xsl:template match="/doc:chapter" mode="dms:get-page-url">
		<xsl:variable name="document-id" select="@id" />	
		<xsl:variable name="parent-id" select="@parent-id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($parent-id, '')]" mode="dms:get-page-chapter-url-index">
			<xsl:with-param name="document-id" select="$document-id" />
		</xsl:apply-templates>
	</xsl:template>

	<xsl:template match="*" mode="dms:get-page-url-index">
		<xsl:value-of select="normalize-space($dms:site_prefix)" /><xsl:value-of select="@href" />
	</xsl:template>

	<xsl:template match="*" mode="dms:get-page-chapter-url-index">
		<xsl:param name="document-id" />
		<xsl:apply-templates select="doc:chapter[@id=$document-id]" mode="dms:get-page-url-index" />
	</xsl:template>

	<!--
		Template to return the URL of the parent page
	-->
	<xsl:template name="dms:get-parent-url">
		<xsl:apply-templates select="/" mode="dms:get-parent-url" />
	</xsl:template>

	<xsl:template match="/doc:*" mode="dms:get-parent-url">
		<xsl:variable name="document-id" select="@parent-id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:get-page-url-index" />
	</xsl:template>

	<xsl:template match="*" mode="dms:get-parent-url" />

	<!-- 
		Template to return the <alt-title> from the <meta> of the current <document> or <documentgroup>
	-->
	<xsl:template name="dms:get-alt-title">
		<xsl:apply-templates select="/doc:*[1]/doc:meta/doc:alt-title" />
	</xsl:template>

	<!-- 
		Template to return the <short-description> from the <meta> of the current <document> or <documentgroup>
	-->
	<xsl:template name="dms:get-short-description">
		<xsl:apply-templates select="/doc:*[1]/doc:meta/doc:short-description" />
	</xsl:template>

	<!-- 
		Template to return the <short-description> from the <meta> of the parent <document> or <documentgroup>
	-->
	<xsl:template name="dms:get-parent-short-description">
		<xsl:variable name="document-id" select="@parent-id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:get-short-description-index" />
	</xsl:template>

	<xsl:template match="doc:short-description" mode="dms:get-short-description-index">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="text()" mode="dms:get-short-description-index" />

	<!-- 
		Template to return the <short-description> from the <meta> of the parent <document> or <documentgroup>
	-->
	<xsl:template name="dms:get-parent-alt-title">
		<xsl:variable name="document-id" select="@parent-id" />	
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($document-id, '')]" mode="dms:get-alt-title-index" />
	</xsl:template>

	<xsl:template match="doc:alt-title" mode="dms:get-alt-title-index">
		<xsl:apply-templates />
	</xsl:template>

	<xsl:template match="text()" mode="dms:get-alt-title-index" />

</xsl:stylesheet>