<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY nbsp "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="2.0"
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents"
				xmlns:advertising="http://www.mad-hacking.net/schema/dms/ext/advertising"
				xmlns:social="http://www.mad-hacking.net/schema/dms/ext/social"
				xmlns:g="http://apis.google.com"
				xmlns:og="http://ogp.me/ns#"
      			xmlns:fb="http://www.facebook.com/2008/fbml" >

	<!-- Import required base stylesheets -->
	<xsl:import href="../base/utility.xsl" />

	<!-- This template should be called from the header of your layout to include auto-generated <meta> tags -->
	<xsl:template name="social:meta-include">
		<xsl:if test="/doc:*[1]/@disable-social-networking != 'yes' or not(/doc:*[1]/@disable-social-networking)">
			<meta property="og:site_name" content="{normalize-space($og:site_name)}" />
			<meta property="fb:admins" content="{normalize-space($og:facebook_default_admin)}" />
			<meta property="fb:app_id" content="{normalize-space($og:facebook_application_id)}" />
			<xsl:call-template name="social:meta-social-networking-ogtype" />
			<xsl:apply-templates select="/" mode="social:meta-social-networking" />
			<meta property="og:image" content="{normalize-space($dms:site_prefix)}{normalize-space($og:default_image)}" />
		</xsl:if>
	</xsl:template>

	<!-- This template creates a <meta> tag to set the og:type to either "website" or "article" -->
	<!-- TODO: Should also handle "blog" and "article" for blogs -->
	<xsl:template name="social:meta-social-networking-ogtype">
		<xsl:choose>
			<xsl:when test="/doc:*[1]/@id=/doc:*[1]/@parent-id">
				<meta property="og:type" content="website" />
			</xsl:when>
			<xsl:otherwise>
				<meta property="og:type" content="article" />
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- This template creates <meta> tags to set the og:title and og:url for most documents -->
	<xsl:template match="/doc:*" mode="social:meta-social-networking">
		<xsl:variable name="alt-title-text"><xsl:call-template name="dms:get-alt-title" /></xsl:variable>
		<xsl:variable name="title-text"><xsl:call-template name="dms:get-page-title-text" /></xsl:variable>
		<xsl:variable name="page-url"><xsl:call-template name="dms:get-page-url" /></xsl:variable>
		<xsl:variable name="short-description"><xsl:call-template name="dms:get-short-description" /></xsl:variable>
		<xsl:choose>
			<xsl:when test="string-length(normalize-space($alt-title-text)) > 0">
				<meta property="og:title" content="{normalize-space($alt-title-text)}" />
			</xsl:when>
			<xsl:otherwise>
				<meta property="og:title" content="{normalize-space($title-text)}" />
			</xsl:otherwise>
		</xsl:choose>
		<meta property="og:url" content="{normalize-space($page-url)}" />
		<meta property="og:description" content="{normalize-space($short-description)}" />		
	</xsl:template>

	<!-- This template creates <meta> tags to set the og:title and og:url for chapters -->
	<xsl:template match="/doc:chapter" mode="social:meta-social-networking">
		<xsl:variable name="alt-title-text"><xsl:call-template name="dms:get-parent-alt-title" /></xsl:variable>
		<xsl:variable name="title-text"><xsl:call-template name="dms:get-parent-title-text" /></xsl:variable>
		<xsl:variable name="page-url"><xsl:call-template name="dms:get-parent-url" /></xsl:variable>
		<xsl:variable name="short-description"><xsl:call-template name="dms:get-parent-short-description" /></xsl:variable>
		<xsl:choose>
			<xsl:when test="string-length(normalize-space($alt-title-text)) > 0">
				<meta property="og:title" content="{normalize-space($alt-title-text)}" />
			</xsl:when>
			<xsl:otherwise>
				<meta property="og:title" content="{normalize-space($title-text)}" />
			</xsl:otherwise>
		</xsl:choose>
		<meta property="og:url" content="{normalize-space($page-url)}" />
		<meta property="og:description" content="{normalize-space($short-description)}" />		
	</xsl:template>


	<!-- This template should be called from the header of your layout to include CSS files used by modules -->
	<xsl:template name="social:css-include">
		<xsl:if test="/doc:*[1]/@disable-social-networking != 'yes' or not(/doc:*[1]/@disable-social-networking)">
			<link rel="stylesheet" type="text/css" href="/style/dms/css/extra/social-networking.css" />
		</xsl:if>
	</xsl:template>

	<!-- This template should be called from the header of your layout to include JavaScript files used by modules -->
	<xsl:template name="social:js-include">
		<xsl:if test="/doc:*[1]/@disable-social-networking != 'yes' or not(/doc:*[1]/@disable-social-networking)">
		</xsl:if>
	</xsl:template>

	<!-- This template should be called from your layout to include random <html> code and JavaScript files used by modules -->
	<xsl:template name="social:html-include">
		<xsl:if test="/doc:*[1]/@disable-social-networking != 'yes' or not(/doc:*[1]/@disable-social-networking)">
			<script type="text/javascript" src="http://apis.google.com/js/plusone.js">{ lang: 'en-GB' }</script>
			<div id="fb-root">&nbsp;</div>
			<script>
				window.fbAsyncInit = function()
				{
					FB.init(
					{
						appId      : '<xsl:value-of select="normalize-space($og:facebook_application_id)" />',
						channelUrl : '<xsl:value-of select="normalize-space($dms:site_prefix)" />/channel.html', // Channel File
						status     : true, // check login status
						cookie     : true, // enable cookies to allow the server to access the session
						xfbml      : true  // parse XFBML
				    });
				};
				// Load the SDK Asynchronously
				(function(d)
				{
					var js, id = 'facebook-jssdk'; 
					if (d.getElementById(id)) {return;}
					js = d.createElement('script');
					js.id = id; js.async = true;
					js.src = "//connect.facebook.net/en_GB/all.js";
					d.getElementsByTagName('head')[0].appendChild(js);
				}(document));
			</script>
		</xsl:if>
	</xsl:template>

	<!-- This template is called automatically from chapter.xsl, document.xsl and documentgroup.xsl -->
	<xsl:template name="social:social-networking">
		<xsl:if test="/doc:*[1]/@disable-social-networking != 'yes' or not(/doc:*[1]/@disable-social-networking)">
			<div class="social-networking">
				<xsl:apply-templates select="/" mode="social:show-social-networking" />
			</div>
		</xsl:if>
	</xsl:template>

	<!-- This template is used to display social-networking controls for <document> and <documentgroup> elements -->
	<xsl:template match="/doc:*" mode="social:show-social-networking">
		<xsl:variable name="alt-title-text"><xsl:call-template name="dms:get-alt-title" /></xsl:variable>
		<xsl:variable name="title-text"><xsl:call-template name="dms:get-page-title-text" /></xsl:variable>
		<xsl:choose>
			<xsl:when test="string-length(normalize-space($alt-title-text)) > 0">
				<xsl:call-template name="social:show-social-networking-buttons">
					<xsl:with-param name="url">
						<xsl:call-template name="dms:get-page-url" />
					</xsl:with-param>
					<xsl:with-param name="title">
						<xsl:value-of select="$alt-title-text" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="social:show-social-networking-buttons">
					<xsl:with-param name="url">
						<xsl:call-template name="dms:get-page-url" />
					</xsl:with-param>
					<xsl:with-param name="title">
						<xsl:value-of select="$title-text" />
					</xsl:with-param>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- This template is used to display social-networking controls for <chapter> elements -->
	<xsl:template match="/doc:chapter" mode="social:show-social-networking">
		<xsl:call-template name="social:show-social-networking-buttons">
			<xsl:with-param name="url">
				<xsl:call-template name="dms:get-parent-url" />
			</xsl:with-param>
			<xsl:with-param name="title">
				<xsl:call-template name="dms:get-parent-title-text" />
			</xsl:with-param>
		</xsl:call-template>
	</xsl:template>
	
	<!-- This template is called with parameters set to actually display the social networking controls -->
	<xsl:template name="social:show-social-networking-buttons">
		<xsl:param name="url" />
		<xsl:param name="title" />
		<!-- Create a Google "+1 button" -->
		<span class="google-like">
			<g:plusone size="medium" count="true">&nbsp;</g:plusone>
		</span>
		<!-- Create a Twitter "tweet" button -->
		<span class="twitter-tweet">				
			<script type="text/javascript" src="http://platform.twitter.com/widgets.js">&nbsp;</script>
			<a href="http://twitter.com/share?url={$url}" class="twitter-share-button"
			   data-count="horizontal" data-text="{normalize-space($title)}" data-url="{$url}">&nbsp;</a>
		</span>
		<!-- Create a Reddit "reddit this" button -->				
		<span class="reddit-this">				
			<script type="text/javascript">
				reddit_url = "<xsl:value-of select="$url" />";
				reddit_title = "<xsl:value-of select="normalize-space($title)" />";
				reddit_newwindow = '1';
			</script>
			<script type="text/javascript" src="http://www.reddit.com/static/button/button1.js">&nbsp;</script>
		</span>
		<!-- Create a StumbleUpon "stumble" button -->				
		<span class="stumble-upon">				
			<script src="http://www.stumbleupon.com/hostedbadge.php?s=1&amp;r={$url}">&nbsp;</script>		
		</span>
		<!-- Create a FaceBook "like" button -->				
		<span class="fb-root-span">
			<fb:like layout="button_count" href="{$url}" send="true" />
		</span>
	</xsl:template>

</xsl:stylesheet>
