<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> <!ENTITY gt "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:linux="http://www.mad-hacking.net/schema/dms/ext/linux" >

	<xsl:template match="linux:shell">
		<xsl:if test="@title">
			<div class="typed-heading"><xsl:value-of select="@title" /></div>
		</xsl:if>
		<xsl:if test="@file">
			<div class="typed-file"><xsl:value-of select="@file" /></div>
		</xsl:if>
		<div class="typed">
			<xsl:apply-templates />
		</div>
		<xsl:if test="@description">
			<div class="typed-footer"><xsl:value-of select="@description" /></div>
		</xsl:if>
	</xsl:template>

	<xsl:template match="linux:shell/linux:command">
	
		<!-- Make the prefix string -->
		<xsl:variable name="prefixstr">
			<xsl:if test="@prefix"><xsl:value-of select="@prefix" />&nbsp;</xsl:if>
		</xsl:variable>		
		
		<!-- Make the role string -->
		<xsl:variable name="rolestr">
			<xsl:if test="@role">(<xsl:value-of select="@role" />)&nbsp;</xsl:if>
		</xsl:variable>		
		
		<!-- Make the host string -->
		<xsl:variable name="hoststr">
			<xsl:if test="@user"><xsl:value-of select="@user" />@</xsl:if>
			<xsl:choose>
				<xsl:when test="@host">
					<xsl:value-of select="@host" />
				</xsl:when>
				<xsl:otherwise>lisa</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<!-- Use the host string to make part one of the command -->
		<xsl:variable name="part1">
			<xsl:choose>
				<xsl:when test="@user">
					<span class="nonroothost"><xsl:copy-of select="$hoststr" />&nbsp;</span>
				</xsl:when>
				<xsl:otherwise>
					<span class="roothost"><xsl:copy-of select="$hoststr" />&nbsp;</span>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<!-- Make part two of the command, the dir and prompt -->
		<xsl:variable name="part2">
			<span class="dir">
				<xsl:choose>
					<xsl:when test="@dir"><xsl:value-of select="@dir" />&nbsp;</xsl:when>
				<xsl:otherwise>~&nbsp;</xsl:otherwise>
				</xsl:choose>
			</span>
			<xsl:choose>
				<xsl:when test="@user">
					<span class="prompt">$&nbsp;</span>
				</xsl:when>
				<xsl:otherwise>
					<span class="prompt">#&nbsp;</span>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
	
		<!-- Output the complete command -->
		<xsl:copy-of select="$prefixstr" /><xsl:copy-of select="$rolestr" /><xsl:copy-of select="$part1" /><xsl:copy-of select="$part2" />
		<span class="command"><xsl:copy-of select="node()" /></span><br />
		
	</xsl:template>

	<xsl:template match="linux:shell/linux:output">
		<pre><xsl:copy-of select="node()" />&nbsp;</pre>
	</xsl:template>	
	
	
	<xsl:template match="linux:shell/linux:emerge">
		<div class="emerge">
			<span class="green">These are the packages that would be merged, in order:</span>
			<br />
			<br />
			Calculating dependencies... done!
		</div>
		<xsl:apply-templates mode="linux:shell-emerge" />
	</xsl:template>
	
	<xsl:template match="linux:shell/linux:emerge/linux:package" mode="linux:shell-emerge">
		[<xsl:choose>
			<xsl:when test="@world">
					<span class="bold-bright-green">ebuild</span>
				</xsl:when>
				<xsl:otherwise>
					<span class="green">ebuild</span>
			</xsl:otherwise>
		</xsl:choose>
		&nbsp;&nbsp;<span class="bold-bright-green">N<xsl:if test="@slot">S</xsl:if><xsl:if test="not(@slot)">&nbsp;</xsl:if></span>&nbsp;&nbsp;&nbsp;]
		<xsl:choose>
			<xsl:when test="@world">
					<span class="bold-bright-green"><xsl:value-of select="@atom" /></span>
				</xsl:when>
				<xsl:otherwise>
					<span class="green"><xsl:value-of select="@atom" /></span>
			</xsl:otherwise>
		</xsl:choose>		
		<xsl:if test="@useon or @useoff">
			&nbsp;USE="<xsl:if test="@useon"><span class="bold-bright-red"><xsl:value-of select="@useon" /></span></xsl:if><xsl:if test="@useoff"><xsl:if test="@useon">&nbsp;</xsl:if><span class="bold-bright-blue"><xsl:value-of select="@useoff" /></span></xsl:if>"
		</xsl:if>	
		<br />
	</xsl:template>
	
</xsl:stylesheet>