<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [ <!ENTITY copy "&#169;"> <!ENTITY nbsp "&#160;"> ]>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents" >

	<xsl:template name="dms:css-include-navigation-chapter">
		<link rel="stylesheet" type="text/css" href="/style/dms/css/navigation/chapter.css" />
	</xsl:template>

	<xsl:template name="dms:navigation-top">
		<xsl:apply-templates mode="dms:navigation-top" select="/doc:chapter" />
	</xsl:template>

	<xsl:template name="dms:navigation-bottom">
		<xsl:apply-templates mode="dms:navigation-bottom" select="/doc:chapter" />
	</xsl:template>

	<xsl:template match="*" mode="dms:navigation-top" />
	<xsl:template match="*" mode="dms:navigation-bottom" />

	<xsl:template match="doc:chapter" mode="dms:navigation-top">
		<div class="navigation-top">
			<xsl:apply-templates select="." mode="dms:navigation" />			
		</div>
	</xsl:template>
	
	<xsl:template match="doc:chapter" mode="dms:navigation-bottom">
		<div class="navigation-bottom">
			<xsl:apply-templates select="." mode="dms:navigation" />			
		</div>
	</xsl:template>

	<xsl:template match="doc:chapter" mode="dms:navigation">
		<xsl:variable name="parent-id" select="@parent-id" />
		<xsl:apply-templates select="document('/site-index.xml', document(''))//descendant::*[@id=concat($parent-id, '')]" mode="dms:navigation-idx">
			<xsl:with-param name="id" select="@id" />
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="doc:document" mode="dms:navigation-idx">
		<xsl:param name="id" />
 		<xsl:apply-templates select="document(@href)" mode="dms:navigation-sub">
			<xsl:with-param name="id" select="$id" />
			<xsl:with-param name="index" select="@href" />
		</xsl:apply-templates>
	</xsl:template>
	
	<xsl:template match="/" mode="dms:navigation-sub">
		<xsl:param name="id" />
		<xsl:param name="index" />
		<xsl:apply-templates select="doc:document/doc:contents" mode="dms:navigation-sub">
			<xsl:with-param name="id" select="$id" />
			<xsl:with-param name="index" select="$index" />
		</xsl:apply-templates>
	</xsl:template>
	
	<!-- 
		This template matches the contents node of the index.xml file.
	 -->
	<xsl:template match="doc:contents" mode="dms:navigation-sub">
		<xsl:param name="id" />
		<xsl:param name="index" />

		<!-- Loop through the chapters looking for the chapter specified in the $id parameter -->		
		<xsl:for-each select="descendant::doc:chapter">
			<xsl:variable name="curpos" select="position()" />

			<!-- Have we found it yet? -->
			<xsl:if test="@id=$id">
	
				<!-- Begin floating divs -->
				<div class="floating">
		
					<!-- Are we the first chapter? -->		
					<xsl:choose>
						<!-- If we aren't the first chapter -->
						<xsl:when test="not($curpos=1)">
							<!-- Find the previous chapter -->
							<xsl:for-each select="ancestor::doc:contents/descendant::doc:chapter">
								<xsl:if test="position()=(($curpos)-1)">
								
									<!-- Display a linked "previous" image... -->
									<div>
										<div>
							 				<a href="{@href}"> 
												<img src="/style/site/icons/left.png" alt="Previous chapter" />			
							 				</a>
										</div>
									</div>
									
									<!-- ...and its title... -->
									<div class="limit">
										<div>
							 				<a href="{@href}">
							 					<!-- ...which we load here. -->
												<xsl:for-each select="document(@href)/doc:chapter" >
													<xsl:value-of select="doc:title" /><br />
												</xsl:for-each>
											</a>		 
										</div>
									</div>
								
								</xsl:if>							
							</xsl:for-each>
						</xsl:when>
						
						<!-- If we are the first chapter -->
						<xsl:otherwise>
							<!-- Display a disabled "previous" image... -->
							<div>
								<div>
									<img src="/style/site/icons/no-left.png" alt="Previous chapter (none)" />			
								</div>
							</div>
							
							<!-- ...and an empty title... -->
							<div class="limit">
								<div>&nbsp;</div>
							</div>
						</xsl:otherwise>
					</xsl:choose>

					<!-- Display the link to the index page -->	
					<div class="middle">
						<div>
							<a href="{$index}">
								<img src="/style/site/icons/up.png" alt="Index" />
							</a>
						</div>
					</div>
			
					<!-- Are we the last chapter? -->		
					<xsl:choose>
						<!-- If we aren't the last chapter -->
						<xsl:when test="not($curpos=last())">
						
							<!-- Find the next chapter -->
							<xsl:for-each select="ancestor::doc:contents/descendant::doc:chapter">
								<xsl:if test="position()=(($curpos)+1)">
								
									<!-- Display its title... -->
									<div class="limit">
										<div class="right">
							 				<a href="{@href}">
							 					<!-- ...which we load here... -->
												<xsl:for-each select="document(@href)/doc:chapter" >
													<xsl:value-of select="doc:title" /><br />
												</xsl:for-each>
											</a>		 
										</div>
									</div>
								
									<!-- ...and a linked "next" image. -->
									<div>
										<div>
							 				<a href="{@href}"> 
												<img src="/style/site/icons/right.png" alt="Next chapter" />			
							 				</a>
										</div>
									</div>
									
									
								</xsl:if>							
							</xsl:for-each>
							
						</xsl:when>
					
						<!-- If we are the last chapter -->
						<xsl:otherwise>
							<!-- Display an empty title... -->
							<div class="limit">
								<div>&nbsp;</div>
							</div>
							
							<!-- ...and a disabled "next" image. -->
							<div>
								<div>
									<img src="/style/site/icons/no-right.png" alt="Next chapter (none)" />			
								</div>
							</div>
						</xsl:otherwise>
					</xsl:choose>
		
				</div>
				<!-- Close floating divs -->

			</xsl:if>
			
		</xsl:for-each>

	</xsl:template>
	
</xsl:stylesheet>