<?xml version="1.0" encoding="UTF-8"?>

<!--
	Copyright 2010 - Max Hacking - Hacking Networked Solutions

	This file is a part of the Hacking Networked Solutions Document Management System XSLT Templates 

    The Hacking Networked Solutions Document Management System is free software: you can 
    redistribute it and/or modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    The Hacking Networked Solutions Document Management System is distributed in the hope
    that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
    License for more details.

    You should have received a copy of the GNU General Public License along with the
    Hacking Networked Solutions Document Management System.  If not, please refer to  
    <http://www.gnu.org/licenses/>.
-->

<xsl:stylesheet version="1.0" 
				xmlns="http://www.w3.org/1999/xhtml"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns:dms="http://www.mad-hacking.net/schema/dms"
				xmlns:doc="http://www.mad-hacking.net/schema/dms/documents" >

	<xsl:template name="dms:css-include-navigation-main-menu">
		<link rel="stylesheet" type="text/css" href="/style/dms/css/navigation/main-menu.css" />
	</xsl:template>

	<!--
		This is the "main-menu" template.  Call this template to display a standard main menu.
	-->
	<xsl:template name="dms:main-menu">
		<xsl:apply-templates select="/" mode="dms:mainmenu" />
	</xsl:template>


	<!--
		This template matches the root node of any document in "mainmenu" mode and starts the <ul> for
		the main menu.
	-->
	<xsl:template match="/" mode="dms:mainmenu">
		<ul>
			<xsl:apply-templates mode="dms:mainmenu" />
		</ul>
	</xsl:template>


	<!--
		This template matches <doc:index> nodes in "mainmenu" mode.  If we are processing a <doc:index> document
		then we do not need to load the site-index file (this is it already) we can just begin processing in 
		"mainmenu-idx" mode.  The @id attribute is set to 'site-index' to select the "Index" button.
	-->
	<xsl:template match="doc:index" mode="dms:mainmenu">
		<xsl:apply-templates mode="dms:mainmenu-idx">
			<xsl:with-param name="id" select="'site-index'" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- 
		This template matches <doc:chapter> nodes in "mainmenu" mode.  It loads the site-index file and starts
		processing it in "mainmenu-idx" mode with the @id attribute set to the parent id of the chapter, ie the
		id of the document to which that chapter belongs.
	-->
	<xsl:template match="doc:chapter" mode="dms:mainmenu">
		<xsl:apply-templates select="document('/site-index.xml', document(''))" mode="dms:mainmenu-idx">
			<xsl:with-param name="id" select="@parent-id" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- 
		This template matches <doc:document> or <doc:documentgroup> nodes in "mainmenu" mode.  It loads the site-index
		file and starts processing it in "mainmenu-idx" mode with the @id attribute set to the id of the current
		<doc:document> or <doc:documentgroup>.
	-->
	<xsl:template match="doc:document|doc:documentgroup|doc:blogpost" mode="dms:mainmenu">
		<xsl:apply-templates select="document('/site-index.xml', document(''))" mode="dms:mainmenu-idx">
			<xsl:with-param name="id" select="@id" />
		</xsl:apply-templates>
	</xsl:template>

	<!--
		This template matches the root node of any document in "mainmenu-idx" mode.  It is used to process the site-index
		file loaded by one of the above templates.  The @id attribute should be set already by the calling template and
		this template simply starts processing the <doc:index> node in "mainmenu-idx" mode passing on the @id parameter.
	-->
	<xsl:template match="/" mode="dms:mainmenu-idx">
		<xsl:param name="id" />
		
		<xsl:apply-templates select="doc:index/*" mode="dms:mainmenu-idx">
			<xsl:with-param name="id" select="$id" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- 
		This template matches the first level <doc:document> or <doc:documentgroup> node in the <doc:index>, which is 
		always the "Home" element.  If it is the node specified in @id then the generated <li> will be marked with 
		class="selected".  As this is the first level element we then apply templates using the same "mainmenu-idx" 
		mode passing on @id.
	-->
	<xsl:template match="doc:index/doc:*" mode="dms:mainmenu-idx">
		<xsl:param name="id" />

		<xsl:choose>
			<xsl:when test="@id=$id">
				<li class="selected"><xsl:value-of select="@short-title" /></li>
			</xsl:when>
			<xsl:otherwise>
				<li><a href="{@href}"><xsl:value-of select="@short-title" /></a></li>
			</xsl:otherwise>
		</xsl:choose>		
		<xsl:apply-templates select="doc:document|doc:documentgroup|doc:external" mode="dms:mainmenu-idx">
			<xsl:with-param name="id" select="$id" />
			<xsl:sort select="@short-title" />
		</xsl:apply-templates>
	</xsl:template>

	<!-- This template matches the same nodes as above when @visibility='hidden' thus hiding the node -->
	<xsl:template match="doc:index/doc:*[@visibility='hidden']" mode="dms:mainmenu-idx" />

	<!-- 
		This template matches the second level <doc:> nodes in the <doc:index>, which are usually below the "Home"
		element.  If it is the node specified in @id then the generated <li> will be marked with class="selected".  As
		we only process first and second level <doc:> nodex we stop here.
	-->
	<xsl:template match="doc:index/doc:*/doc:*" mode="dms:mainmenu-idx">
		<xsl:param name="id" />

		<xsl:choose>
			<xsl:when test="@id=$id">
				<li class="selected"><xsl:value-of select="@short-title" /></li>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<xsl:when test="descendant::doc:document[@id=$id]|descendant::doc:documentgroup[@id=$id]|descendant::doc:external[@id=$id]">
						<li class="selected"><a href="{@href}"><xsl:value-of select="@short-title" /></a></li>
					</xsl:when>
					<xsl:otherwise>
						<li><a href="{@href}"><xsl:value-of select="@short-title" /></a></li>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
	
	<!-- This template matches the same nodes as above when @visibility='hidden' thus hiding the node -->
	<xsl:template match="doc:index/doc:*/doc:*[@visibility='hidden']" mode="dms:mainmenu-idx" />

</xsl:stylesheet>
